nengo\_spa\.algebras
====================

.. automodule:: nengo_spa.algebras
   :members:
   :undoc-members:
   :imported-members:

   .. autosummary::

      AbstractAlgebra
      ElementSidedness
      HrrAlgebra
      VtbAlgebra
      TvtbAlgebra
